@@ -1,7 +1,8 @@
+import re
 
 
-def create_request(text, message_id=0, user_id=0, session_id=0):
-    norm_text = text # todo: really normalize it
+def create_request(text, message_id=0, user_id=0, session_id=0, new_session=False):
+    norm_text = re.sub('[^a-zа-яё0-9]+', ' ', text.lower())  # todo: really normalize it
     raw_req = {
       "meta": {
         "locale": "ru-RU",
@@ -25,9 +26,9 @@ def create_request(text, message_id=0, user_id=0, session_id=0):
         }
       },
       "session": {
-        "new": bool(message_id == 0),
+        "new": bool(new_session),
         "message_id": message_id,
-        "session_id": "botank-{}".format(session_id),  # todo: maybe create a new session
+        "session_id": "botank-{}".format(session_id),
         "skill_id": "botank-f5rd-4079-a14b-788652932056",  # todo: maybe insert the provided skill id
         "user_id": "BOTANK{}".format(user_id),
       },
